#!/bin/bash

if [ -d "dynamicring"]
then
    echo "dynamicring already exists."
    exit 1
fi


#Create directories: scenario.xml for all routing agents
for scen in dynamicring; do
    for par in Backoff_Ring Pure_Ring SLR_Ring Proba_Ring Backoff_NoRing SLR_NoRing Proba_NoRing; do
	for rng in `seq 0 9`; do
	    dir="${scen}/${par}/run${rng}"
	    mkdir -p $dir
	    cp scenario.xml ${dir}/scenario.xml
	    if [ $par = "Pure_Ring" ]
	    then
		sed -i 's/PureFloodingRouting/PureFloodingDynamicRingRouting rangeBig_nm="1000000" rangeSmall_nm="700000"/g' ${dir}/scenario.xml
		sed -i 's/DEDeN enabled="false"/DEDeN enabled="true"/g' ${dir}/scenario.xml
	    elif [ $par = "SLR_NoRing" ]
	    then
		sed -i 's/PureFloodingRouting/SLRRouting commRangeSetup_nm="800000" anchor1id="0" anchor2id="1"/g' ${dir}/scenario.xml
	    elif [ $par = "SLR_Ring" ]
	    then
		sed -i 's/PureFloodingRouting/SLRDynamicRingRouting commRangeSetup_nm="800000" anchor1id="0" anchor2id="1" rangeBig_nm="1000000" rangeSmall_nm="700000"/g' ${dir}/scenario.xml
		sed -i 's/DEDeN enabled="false"/DEDeN enabled="true"/g' ${dir}/scenario.xml
	    elif [ $par = "Backoff_NoRing" ]
	    then
		sed -i 's/routing defaultBackoffWindow="10000"/routing/g' ${dir}/scenario.xml #backoffrngseed
		sed -i 's/PureFloodingRouting/BackoffFloodingRouting/g' ${dir}/scenario.xml
		sed -i 's/DEDeN enabled="false"/DEDeN enabled="true"/g' ${dir}/scenario.xml
	    elif [ $par = "Backoff_Ring" ]
	    then
		sed -i 's/routing defaultBackoffWindow="10000"/routing/g' ${dir}/scenario.xml
		sed -i 's/PureFloodingRouting/BackoffFloodingDynamicRingRouting rangeBig_nm="1000000" rangeSmall_nm="700000"/g' ${dir}/scenario.xml
		sed -i 's/DEDeN enabled="false"/DEDeN enabled="true"/g' ${dir}/scenario.xml
	    elif [ $par = "Proba_NoRing" ]
	    then
		sed -i 's/PureFloodingRouting/ProbaFloodingRouting probability="0.06"/g' ${dir}/scenario.xml
	    elif [ $par = "Proba_Ring" ]
	    then
		sed -i 's/PureFloodingRouting/ProbaFloodingDynamicRingRouting probability="0.1" rangeBig_nm="1000000" rangeSmall_nm="700000"/g' ${dir}/scenario.xml
		sed -i 's/DEDeN enabled="false"/DEDeN enabled="true"/g' ${dir}/scenario.xml
	    fi
	done
    done
done


#Run bitsimulator

for scen in dynamicring; do
    for par in SLR_Ring; do
	for rng in 0; do #start with slr ring, not in parallel with others because need its deden and slr init
	    dir="${scen}/${par}/run${rng}"
	    echo Running ${scen} ${par} with seed ${rng}
	    if [ $par = "SLR_Ring" ] 
	    then
		time ./bitsimulator -D ${dir} --backoffRNGSeed ${rng} --doNotUseNeighboursList --deden #&> /dev/null
	    fi
	    awk '$1 == "1" &&  $6=="1003"'  ${dir}/events.log > ${dir}/receivedata.log
	    awk '$1 == "0" &&  $7=="1003"'  ${dir}/events.log > ${dir}/senddata.log
	    awk '$1 == "0"'  ${dir}/events.log > ${dir}/allsend.log
	done
    done
done

for scen in dynamicring; do
    for par in SLR_Ring; do
	#beginpar
	for rng in `seq 1 9`; do 
	    dir="${scen}/${par}/run${rng}"
	    echo Running ${scen} ${par} with seed ${rng}
	    if [ $par = "SLR_Ring" ] 
	    then
		cp ${scen}/SLR_Ring/run0/densityError.log ${dir}/densityError.log
		cp ${scen}/SLR_Ring/run0/histo.log ${dir}/histo.log
		cp ${scen}/SLR_Ring/run0/SLRPositions.log ${dir}/SLRPositions.log
		time ./bitsimulator -D ${dir} --backoffRNGSeed ${rng} --doNotUseNeighboursList --dedenLoadEstimationFromFile --loadSLRPositionsFromFile #&> /dev/null
	    fi
	    awk '$1 == "1" &&  $6=="1003"'  ${dir}/events.log > ${dir}/receivedata.log
	    awk '$1 == "0" &&  $7=="1003"'  ${dir}/events.log > ${dir}/senddata.log
	    awk '$1 == "0"'  ${dir}/events.log > ${dir}/allsend.log
	done
	#endpar
    done
done
#waitpar

for scen in dynamicring; do
    for par in Backoff_Ring Pure_Ring Proba_Ring Backoff_NoRing SLR_NoRing Proba_NoRing; do
	#beginpar
	for rng in 0; do
	    dir="${scen}/${par}/run${rng}"
	    echo Running ${scen} ${par} with seed ${rng}	    
	    if [ $par = "Proba_NoRing" ] 
	    then
		time ./bitsimulator -D ${dir} --backoffRNGSeed ${rng} --doNotUseNeighboursList --probability 0.06 #&> /dev/null #--genericNodesRNGSeed 
	    elif [ $par = "Proba_Ring" ] 
	    then
		cp ${scen}/SLR_Ring/run0/densityError.log ${dir}/densityError.log
		cp ${scen}/SLR_Ring/run0/histo.log ${dir}/histo.log
		time ./bitsimulator -D ${dir} --backoffRNGSeed ${rng} --doNotUseNeighboursList --dedenLoadEstimationFromFile --probability 0.1 #&> /dev/null
	    elif  [ $par = "SLR_NoRing" ]
	    then
		cp ${scen}/SLR_Ring/run0/SLRPositions.log ${dir}/SLRPositions.log
		time ./bitsimulator -D ${dir} --backoffRNGSeed ${rng} --doNotUseNeighboursList --loadSLRPositionsFromFile #&> /dev/null
	    elif  [ $par = "Backoff_NoRing" ] ||  [ $par = "Backoff_Ring" ]  ||  [ $par = "Pure_Ring" ]  ||  [ $par = "SLR_Ring" ]
	    then
		cp ${scen}/SLR_Ring/run0/densityError.log ${dir}/densityError.log
		cp ${scen}/SLR_Ring/run0/histo.log ${dir}/histo.log
		time ./bitsimulator -D ${dir} --backoffRNGSeed ${rng} --doNotUseNeighboursList --dedenLoadEstimationFromFile #&> /dev/null	
	    fi
	    awk '$1 == "1" &&  $6=="1003"'  ${dir}/events.log > ${dir}/receivedata.log
	    awk '$1 == "0" &&  $7=="1003"'  ${dir}/events.log > ${dir}/senddata.log
	    awk '$1 == "0"'  ${dir}/events.log > ${dir}/allsend.log
	done
	for rng in `seq 1 9`; do
	    dir="${scen}/${par}/run${rng}"
	    echo Running ${scen} ${par} with seed ${rng}
	    if [ $par = "Proba_NoRing" ] 
	    then
		time ./bitsimulator -D ${dir} --backoffRNGSeed ${rng} --doNotUseNeighboursList --probability 0.06 #&> /dev/null
	    elif  [ $par = "Proba_Ring" ]
	    then
		cp ${scen}/SLR_Ring/run0/densityError.log ${dir}/densityError.log
		cp ${scen}/SLR_Ring/run0/histo.log ${dir}/histo.log
		time ./bitsimulator -D ${dir} --backoffRNGSeed ${rng} --doNotUseNeighboursList --probability 0.1 --dedenLoadEstimationFromFile #&> /dev/null
	    elif [ $par = "SLR_NoRing" ] 
	    then
		cp ${scen}/SLR_Ring/run0/SLRPositions.log ${dir}/SLRPositions.log
		time ./bitsimulator -D ${dir} --backoffRNGSeed ${rng} --doNotUseNeighboursList --loadSLRPositionsFromFile #&> /dev/null
	    elif  [ $par = "Backoff_NoRing" ] ||  [ $par = "Backoff_Ring" ]  ||  [ $par = "Pure_Ring" ]
	    then
		cp ${scen}/SLR_Ring/run0/densityError.log ${dir}/densityError.log
		cp ${scen}/SLR_Ring/run0/histo.log ${dir}/histo.log
		time ./bitsimulator -D ${dir} --backoffRNGSeed ${rng} --doNotUseNeighboursList --dedenLoadEstimationFromFile #&> /dev/null	
	    fi
	    awk '$1 == "1" &&  $6=="1003"'  ${dir}/events.log > ${dir}/receivedata.log
	    awk '$1 == "0" &&  $7=="1003"'  ${dir}/events.log > ${dir}/senddata.log
	    awk '$1 == "0"'  ${dir}/events.log > ${dir}/allsend.log
	    rm ${dir}/events.log
	done
	#endpar
    done
done
#waitpar

for scen in dynamicring; do
    for par in Backoff_Ring Pure_Ring SLR_Ring Proba_Ring Backoff_NoRing SLR_NoRing Proba_NoRing; do
	if [ $par = "SLR_NoRing" ] ||  [ $par = "SLR_Ring" ]
	then
	    echo "seed packet_sequence_number sending_nodes_per_packet destination_reached" > ${scen}/${par}/results.txt
	else
	    echo "seed packet_sequence_number sending_nodes_per_packet receiving_nodes_per_packet" > ${scen}/${par}/results.txt
	fi
	#beginpar
	for rng in `seq 0 9`; do
	    dir="${scen}/${par}/run${rng}"
	    for p in `seq 0 49` #change depending on number of packets
	    do
		send=`awk -v P="$p" '$10==P' ${dir}/senddata.log | sort -k3,3 -u | wc -l`
		#sendt=`awk -v P="$p" '$3 == "2" &&  $9==P' ${dir}/senddata.log | awk 'NR==1{print $2; exit}'`
		if [ $par = "SLR_NoRing" ] || [ $par = "SLR_Ring" ]
		then
		    receive=`awk -v P="$p" '$3=="3" &&  $8==P' ${dir}/receivedata.log | sort -k3,3 -u | wc -l`
		    #receivet=`awk -v P="$p" '$3=="3" &&  $8==P' ${dir}/receivedata.log | sort -k3,3 -u | sort -k2,2 | awk 'END{print $2; exit}'`
		else
		    receive=`awk -v P="$p" '$8==P' ${dir}/receivedata.log | sort -k3,3 -u | wc -l`
		    #receivet=`awk -v P="$p" '$8==P' ${dir}/receivedata.log | sort -k3,3 -u | sort -k2,2 | awk 'END{print $2; exit}'`
		fi
		echo ${rng} ${p} ${send} ${receive} >>  ${scen}/${par}/results.txt
	    done
	done
	awk1=`awk '{s+=$3} END{print s/(NR - 1)}'  ${scen}/${par}/results.txt`
	awk2=`awk '{t+=$4} END{print t/(NR - 1)}'  ${scen}/${par}/results.txt`
	echo average number of forwarders, number of receivers respectively: ${awk1} ${awk2} >>  ${scen}/${par}/finalresults.txt
	#endpar
    done
done
#waitpar
